pub enum RemotePartitionDeleteState {
DeletePartitionMarked,
DeletePartitionStarted,
DeletePartitionFinished,
}Expand description
Lifecycle state of a remote partition deletion.
DeletePartitionMarked ──► DeletePartitionStarted ──► DeletePartitionFinishedVariants
DeletePartitionMarked
The partition has been marked for deletion of all its remote segments.
DeletePartitionStarted
Deletion of the partition’s remote segments has begun.
DeletePartitionFinished
All remote segments for the partition have been deleted.
Implementations
Sourceimpl RemotePartitionDeleteState
impl RemotePartitionDeleteState
Sourcepub fn is_valid_transition(from: Option<Self>, target: Self) -> bool
pub fn is_valid_transition(from: Option<Self>, target: Self) -> bool
true if a partition currently in from (or never marked, when
from is None) may transition to target.